==> codemodder-0.70.0.tar.gz: codemodder-0.70.0/src/core_codemods/fix_deprecated_logging_warn.py <==
import libcst as cst
from codemodder.codemods.api import SemgrepCodemod, ReviewGuidance
from codemodder.codemods.utils_mixin import NameResolutionMixin


class FixDeprecatedLoggingWarn(SemgrepCodemod, NameResolutionMixin):
    NAME = "fix-deprecated-logging-warn"
    SUMMARY = "Replace Deprecated `logging.warn`"
    REVIEW_GUIDANCE = ReviewGuidance.MERGE_WITHOUT_REVIEW
    DESCRIPTION = "Replace deprecated `logging.warn` with `logging.warning`"
    REFERENCES = [
        {
            "url": "https://docs.python.org/3/library/logging.html#logging.Logger.warning",
            "description": "",
        },
    ]
    _module_name = "logging"

    @classmethod
    def rule(cls):
        return """
        rules:
            - pattern-either:
              - patterns:
                - pattern: logging.warn(...)
                - pattern-inside: |
                    import logging
                    ...
              - patterns:
                - pattern: logging.getLogger(...).warn(...)
                - pattern-inside: |
                    import logging
                    ...
              - patterns:
                - pattern: $VAR.warn(...)
                - pattern-inside: |
                    import logging
                    ...
                    $VAR = logging.getLogger(...)
                    ...

        """

    def on_result_found(self, original_node, updated_node):
        warning = cst.Name(value="warning")
        match original_node.func:
            case cst.Name():
                self.add_needed_import(self._module_name, "warning")
                self.remove_unused_import(original_node.func)
                return updated_node.with_changes(func=warning)
            case cst.Attribute():
                return updated_node.with_changes(
                    func=updated_node.func.with_changes(attr=warning)
                )
        return original_node

==> codemodder-0.81.0.tar.gz: codemodder-0.81.0/src/core_codemods/fix_deprecated_logging_warn.py <==
import libcst as cst
from codemodder.codemods.utils_mixin import NameResolutionMixin
from core_codemods.api import (
    Metadata,
    Reference,
    ReviewGuidance,
    SimpleCodemod,
)


class FixDeprecatedLoggingWarn(SimpleCodemod, NameResolutionMixin):
    metadata = Metadata(
        name="fix-deprecated-logging-warn",
        summary="Replace Deprecated `logging.warn`",
        review_guidance=ReviewGuidance.MERGE_WITHOUT_REVIEW,
        references=[
            Reference(
                url="https://docs.python.org/3/library/logging.html#logging.Logger.warning"
            ),
        ],
    )
    change_description = "Replace deprecated `logging.warn` with `logging.warning`"
    _module_name = "logging"
    detector_pattern = """
        rules:
            - pattern-either:
              - patterns:
                - pattern: logging.warn(...)
                - pattern-inside: |
                    import logging
                    ...
              - patterns:
                - pattern: logging.getLogger(...).warn(...)
                - pattern-inside: |
                    import logging
                    ...
              - patterns:
                - pattern: $VAR.warn(...)
                - pattern-inside: |
                    import logging
                    ...
                    $VAR = logging.getLogger(...)
                    ...

        """

    def on_result_found(self, original_node, updated_node):
        warning = cst.Name(value="warning")
        match original_node.func:
            case cst.Name():
                self.add_needed_import(self._module_name, "warning")
                self.remove_unused_import(original_node.func)
                return updated_node.with_changes(func=warning)
            case cst.Attribute():
                return updated_node.with_changes(
                    func=updated_node.func.with_changes(attr=warning)
                )
        return original_node
